<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Homepage_Blog_Single' ) ) {
    
    /**
     * Productive_Theme_Customiser_Homepage_Blog_Single
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Homepage_Blog_Single extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            // Section
            $wp_customise->add_section(
                'productive_ecommerce_homepage_blog_single_options',
                array(
                    'title' => __( 'Blog Page', 'productive-ecommerce' ),
                    'description' => __( 'Blog Pages Options', 'productive-ecommerce' ),
                    'panel' => 'productive_ecommerce_theme_options',
                    'priority' => 100,
                    'capability' => 'edit_theme_options',
                )
                );
                        
            // add a setting for productive_ecommerce_single_post_use_drop_caps control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_single_post_use_drop_caps',
                array(
                    'type' => 'theme_mod',
                    'default' => false,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            $wp_customise->add_control(
                'productive_ecommerce_single_post_use_drop_caps',
                array(
                    'type' => 'checkbox',
                    'priority' => 10,
                    'section' => 'productive_ecommerce_homepage_blog_single_options',
                    'label' => __( 'Use Drop Caps', 'productive-ecommerce' ),
                    'description' => __( 'Use Drop Caps on Post & Pages', 'productive-ecommerce' ),
                    // 'active_callback' => 'is_front_page',
                )
                );
            
            // add a setting for productive_ecommerce_single_post_content_alignment control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_single_post_content_alignment',
                array(
                    'type' => 'theme_mod',
                    'default' => 'justify',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_single_post_content_alignment',
                array(
                    'type' => 'select',
                    'priority' => 30,
                    'section' => 'productive_ecommerce_homepage_blog_single_options',
                    'label' => __( 'Blog Page Content Alignment', 'productive-ecommerce' ),
                    'description' => '',
                    'choices' => array(
                        'left' => __( 'Left', 'productive-ecommerce' ),
                        'right' => __( 'Rigt', 'productive-ecommerce' ),
                        'center' => __( 'Center', 'productive-ecommerce' ),
                        'justify' => __( 'Justify', 'productive-ecommerce' ),
                    ),
                )
            );
            
            // add a setting for productive_ecommerce_single_post_display_category control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_single_post_display_category',
                array(
                    'type' => 'theme_mod',
                    'default' => '1',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_single_post_display_category',
                array(
                    'type' => 'select',
                    'priority' => 40,
                    'section' => 'productive_ecommerce_homepage_blog_single_options',
                    'label' => __( 'Display Category', 'productive-ecommerce' ),
                    'description' => '',
                    'choices' => productive_global_get_show_or_hide_options(),
                )
            );
            
            // add a setting for productive_ecommerce_single_post_display_author control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_single_post_display_author',
                array(
                    'type' => 'theme_mod',
                    'default' => '1',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_single_post_display_author',
                array(
                    'type' => 'select',
                    'priority' => 50,
                    'section' => 'productive_ecommerce_homepage_blog_single_options',
                    'label' => __( 'Display Post Author', 'productive-ecommerce' ),
                    'description' => '',
                    'choices' => productive_global_get_show_or_hide_options(),
                )
            );
            
            // add a setting for productive_ecommerce_single_post_display_which_date control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_single_post_display_which_date',
                array(
                    'type' => 'theme_mod',
                    'default' => 'last_updated_date',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_single_post_display_which_date',
                array(
                    'type' => 'select',
                    'priority' => 60,
                    'section' => 'productive_ecommerce_homepage_blog_single_options',
                    'label' => __( 'Display Post Date', 'productive-ecommerce' ),
                    'description' => '',
                    'choices' => array(
                        'original_posted_date' => __( 'Original Posted Date', 'productive-ecommerce' ),
                        'last_updated_date' => __( 'Last Updated  Date', 'productive-ecommerce' ),
                        'hide_posted_date' => __( 'Hide Posted Date', 'productive-ecommerce' ),
                    ),
                )
            );
            
        }
        
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Homepage_Blog_Single', 'register' ) );
    
} // End of if class exists




/**
 * Method productive_ecommerce_single_post_use_drop_caps.
 *
 * @param string $class ''.
 */
function productive_ecommerce_single_post_use_drop_caps( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_single_post_use_drop_caps', false );
}

/**
 * 
 * Method productive_ecommerce_single_post_content_container_width.
 *
 * @param string $class ''.
 */
function productive_ecommerce_single_post_content_container_width( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_single_post_content_container_width', 0 );
}

/**
 * Method productive_ecommerce_single_post_content_alignment.
 *
 * @param string $class ''.
 */
function productive_ecommerce_single_post_content_alignment( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_single_post_content_alignment', 'justify' );
}

/**
 * Method productive_ecommerce_single_post_display_category.
 *
 * @param string $class ''.
 */
function productive_ecommerce_single_post_display_category( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_single_post_display_category', '1' );
}

/**
 * Method productive_ecommerce_single_post_display_author.
 *
 * @param string $class ''.
 */
function productive_ecommerce_single_post_display_author( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_single_post_display_author', '1' );
}

/**
 * Method productive_ecommerce_single_post_display_which_date.
 *
 * @param string $class ''.
 */
function productive_ecommerce_single_post_display_which_date( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_single_post_display_which_date', 'last_updated_date' );
}
