<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Commerce_Categories' ) ) {
    
    /**
     * Productive_Theme_Customiser_Commerce_Categories
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Commerce_Categories extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            // Section
            $wp_customise->add_section(
                'productive_ecommerce_theme_commerce_categories',
                array(
                    'title' => __( 'Product Archives', 'productive-ecommerce' ),
                    'description' => __( 'Product Categories (Archives) Options', 'productive-ecommerce' ),
                    'panel' => 'productive_ecommerce_theme_woocommerce_options',
                    'priority' => 20,
                    'capability' => 'edit_theme_options',
                )
                );
            
            // add a setting for productive_ecommerce_show_sidebars_always_in_woo_archives control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_show_sidebars_always_in_woo_archives',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_show_sidebars_always_in_woo_archives',
                array(
                    'type' => 'checkbox',
                    'priority' => 10,
                    'section' => 'productive_ecommerce_theme_commerce_categories',
                    'label' => __( 'Always show Sidebar on WooCommerce Archives?', 'productive-ecommerce' ),
                    'description' => __( 'If enabled, sidebars will always be displayed on Product catalog and archives, even if the site is set to one-column layout)', 'productive-ecommerce' ),
                )
                );
            
        }
        
        
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Commerce_Categories', 'register' ) );
    
} // End of if class exists



/**
 * Method productive_ecommerce_show_sidebars_always_in_woo_archives.
 *
 * @param string $class ''.
 */
function productive_ecommerce_show_sidebars_always_in_woo_archives( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_show_sidebars_always_in_woo_archives', true );
}




// COMMERCE CATEGORIES
/**
 * Method productive_ecommerce_enable_subcategories.
 *
 * @param string $class ''.
 */
function productive_ecommerce_enable_subcategories( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_enable_subcategories', true );
}
add_action( 'display_productive_ecommerce_enable_subcategories', 'productive_ecommerce_enable_subcategories' );

/**
 * Method productive_ecommerce_subcategories_items_per_row_to_display.
 *
 * @param string $class ''.
 */
function productive_ecommerce_subcategories_items_per_row_to_display( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_subcategories_items_per_row_to_display', 5 );
}
add_action( 'display_productive_ecommerce_subcategories_items_per_row_to_display', 'productive_ecommerce_subcategories_items_per_row_to_display' );