<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Header' ) ) {
    
    /**
     * Productive_Theme_Customiser_Header
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Header extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            // Section
            $wp_customise->add_section(
                'productive_ecommerce_theme_header',
                array(
                    'title' => __( 'Header Options', 'productive-ecommerce' ),
                    'description' => __( 'Header Options', 'productive-ecommerce' ),
                    'panel' => 'productive_ecommerce_theme_options',
                    'priority' => 10,
                    'capability' => 'edit_theme_options',
                )
                );
            
            // add a setting for productive_ecommerce_the_logo_size control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_the_logo_size',
                array(
                    'type' => 'theme_mod',
                    'default' => PRODUCTIVE_ECOMMERCE_THE_LOGO_WIDTH_DEFAULT,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_absint'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_the_logo_size',
                array(
                    'type' => 'number',
                    'priority' => 30,
                    'section' => 'productive_ecommerce_theme_header',
                    'label' => __( 'Logo Width (px)', 'productive-ecommerce' ),
                    'description' => __( 'Increases or decreases logo width in px - height adjusts automatically.', 'productive-ecommerce' ),
                    'input_attrs' => array(
                        'min' => PRODUCTIVE_ECOMMERCE_THE_LOGO_WIDTH_MIN,
                        'max' => PRODUCTIVE_ECOMMERCE_THE_LOGO_WIDTH_MAX,
                        'step' => 10,
                    ),
                )
            );
            
            // add a setting for vertical_spacing control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_the_logo_vertical_spacing',
                array(
                    'type' => 'theme_mod',
                    'default' => 30,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_absint'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_the_logo_vertical_spacing',
                array(
                    'type' => 'number',
                    'priority' => 40,
                    'section' => 'productive_ecommerce_theme_header',
                    'label' => __( 'Logo Vertical Spacing (px)', 'productive-ecommerce' ),
                    'description' => __( 'Increases or decreases the spacing above and below the logo.', 'productive-ecommerce' ),
                    'input_attrs' => array(
                        'min' => 10,
                        'max' => 100,
                        'step' => 5,
                    ),
                )
            );
            
            // add a setting for productive_ecommerce_enable_header_search control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_enable_header_search',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_enable_header_search',
                array(
                    'type' => 'checkbox',
                    'priority' => 60,
                    'section' => 'productive_ecommerce_theme_header',
                    'label' => __( 'Show Header Search Option?', 'productive-ecommerce' ),
                    'description' => __( 'Display search box in the header', 'productive-ecommerce' ),
                    // 'active_callback' => 'is_front_page',
                )
                );
            
            // add a setting for productive_ecommerce_enable_header_account control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_enable_header_account',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_enable_header_account',
                array(
                    'type' => 'checkbox',
                    'priority' => 70,
                    'section' => 'productive_ecommerce_theme_header',
                    'label' => __( 'Show My Account Icon in Header?', 'productive-ecommerce' ),
                    'description' => __( 'Show login/logout icon in the header', 'productive-ecommerce' ),
                    // 'active_callback' => 'is_front_page',
                )
                );
            
            // add a setting for productive_ecommerce_header_megamenu_option control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_header_megamenu_option',
                array(
                    'type' => 'theme_mod',
                    'default' => 'default',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_header_megamenu_option',
                array(
                    'type' => 'select',
                    'priority' => 80,
                    'section' => 'productive_ecommerce_theme_header',
                    'label' => __( 'Select Header Menu Option', 'productive-ecommerce' ),
                    'description' => __( 'Select third party mega menu, if a mega menu is implemented to avoid loading the default menu scripts.', 'productive-ecommerce' ),
                    'choices' => array(
                        'default' => __( 'Theme&#39;s Default Menu', 'productive-ecommerce' ),
                        'megamenu' => __( 'Third Party Mega Menu', 'productive-ecommerce' ),
                    ),
                )
            );
            
        }
        
        
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Header', 'register' ) );
    
} // End of if class exists



/**
 * Method productive_ecommerce_header_style.
 *
 * @param string $class ''.
 */
function productive_ecommerce_header_style( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_header_style', PRODUCTIVE_ECOMMERCE_CURRENT_THEME_TEXT_DOMAIN );
}

/**
 * Method productive_ecommerce_header_colour_mode.
 *
 * @param string $class ''.
 */
function productive_ecommerce_header_colour_mode( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_header_colour_mode', 'header_colour_mode_dark' );
}

/**
 * 
 * Method productive_ecommerce_the_logo_size.
 *
 * @param string $class ''.
 */
function productive_ecommerce_the_logo_size( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_the_logo_size', PRODUCTIVE_ECOMMERCE_THE_LOGO_WIDTH_DEFAULT );
}

/**
 * 
 * Method productive_ecommerce_the_logo_vertical_spacing.
 *
 * @param string $class ''.
 */
function productive_ecommerce_the_logo_vertical_spacing( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_the_logo_vertical_spacing', 30 );
}

/**
 * Method productive_ecommerce_enable_header_search.
 *
 * @param string $class ''.
 */
function productive_ecommerce_enable_header_search( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_enable_header_search', true );
}
add_action( 'display_productive_ecommerce_enable_header_search', 'productive_ecommerce_enable_header_search' );

/**
 * Method productive_ecommerce_enable_header_account.
 *
 * @param string $class ''.
 */
function productive_ecommerce_enable_header_account( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_enable_header_account', true );
}

/**
 * Method productive_ecommerce_header_megamenu_option.
 *
 * @param string $class ''.
 */
function productive_ecommerce_header_megamenu_option( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_header_megamenu_option', 'default' );
}