<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}

if ( ! class_exists( 'Productive_Theme_Customiser_Homepage_Products_Latest' ) ) {
    
    /**
     * Productive_Theme_Customiser_Homepage_Products_Latest
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Homepage_Products_Latest extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            
            // Section
            $panel = 'productive_ecommerce_theme_homepage_options';
            if ( productive_ecommerce_is_productive_style_active() || productive_ecommerce_is_productive_style_extra_active() ) {
                $panel = 'productive_style_theme_options_homepage';
            }
            $wp_customise->add_section(
                'productive_ecommerce_homepage_products_latest_options',
                array(
                    'title' => __( 'Latest Products', 'productive-ecommerce' ),
                    'description' => __( 'Homepage Newest Products', 'productive-ecommerce' ),
                    'panel' => $panel,
                    'priority' => 50,
                    'capability' => 'edit_theme_options',
                )
                );
            
            // add a setting for productive_ecommerce_homepage_products_latest_enable control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_homepage_products_latest_enable',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            $wp_customise->add_control(
                'productive_ecommerce_homepage_products_latest_enable',
                array(
                    'type' => 'checkbox',
                    'priority' => 10,
                    'section' => 'productive_ecommerce_homepage_products_latest_options',
                    'label' => __( 'Enable Latest Products Section?', 'productive-ecommerce' ),
                    'description' => __( 'Display latest products section in the Homepage', 'productive-ecommerce' ),
                    // 'active_callback' => 'is_front_page',
                )
                );
            
            // add a setting for productive_ecommerce_homepage_products_latest_section_title control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_homepage_products_latest_section_title',
                array(
                    'type' => 'theme_mod',
                    'default' => __( 'Latest Products', 'productive-ecommerce' ),
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_homepage_products_latest_section_title',
                array(
                    'type' => 'text',
                    'priority' => 20,
                    'section' => 'productive_ecommerce_homepage_products_latest_options',
                    'label' => __( 'Section Title', 'productive-ecommerce' ),
                    'description' => __( 'Section Title (e.g Latest Products)', 'productive-ecommerce' ),
                )
            );
            
            // add a setting for productive_ecommerce_homepage_products_latest_num_cols control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_homepage_products_latest_num_cols',
                array(
                    'type' => 'theme_mod',
                    'default' => 4,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_absint'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_homepage_products_latest_num_cols',
                array(
                    'type' => 'number',
                    'priority' => 30,
                    'section' => 'productive_ecommerce_homepage_products_latest_options',
                    'label' => __( 'Number of columns per row', 'productive-ecommerce' ),
                    'description' => __( 'The number of products to show in a row.', 'productive-ecommerce' ),
                    'input_attrs' => array(
                        'min' => 2,
                        'max' => 7,
                        'step' => 1,
                    ),
                )
            );
            
            // add a setting for productive_ecommerce_homepage_products_latest_num_rows control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_homepage_products_latest_num_rows',
                array(
                    'type' => 'theme_mod',
                    'default' => 1,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_absint'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_homepage_products_latest_num_rows',
                array(
                    'type' => 'number',
                    'priority' => 40,
                    'section' => 'productive_ecommerce_homepage_products_latest_options',
                    'label' => __( 'Number of rows', 'productive-ecommerce' ),
                    'description' => '',
                    'input_attrs' => array(
                        'min' => 1,
                        'max' => 2,
                        'step' => 1,
                    ),
                )
            );
            /*
            // add a setting for productive_ecommerce_homepage_products_latest_order control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_homepage_products_latest_order',
                array(
                    'type' => 'theme_mod',
                    'default' => '1',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_absint'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_homepage_products_latest_order',
                array(
                    'type' => 'number',
                    'priority' => 50,
                    'section' => 'productive_ecommerce_homepage_products_latest_options',
                    'label' => __( 'Section Position', 'productive-ecommerce' ),
                    'description' => __( 'Section with lowest position is placed at the top of the page.', 'productive-ecommerce' ),
                    'input_attrs' => array(
                        'min' => 1,
                        'max' => 10,
                        'step' => 1,
                    ),
                )
            );
            
            // add a setting for productive_ecommerce_homepage_products_latest_style control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_homepage_products_latest_style',
                array(
                    'type' => 'theme_mod',
                    'default' => 'style_1',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_homepage_products_latest_style',
                array(
                    'type' => 'select',
                    'priority' => 60,
                    'section' => 'productive_ecommerce_homepage_products_latest_options',
                    'label' => __( 'Layout Style', 'productive-ecommerce' ),
                    'description' => '',
                    'choices' => array (
                        'style_1' => __( 'Style 1', 'productive-ecommerce' ),
                        'style_2' => __( 'Style 2', 'productive-ecommerce' ),
                    )
                )
            );
            
            // add a setting for productive_ecommerce_homepage_products_latest_section_bg_color control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_homepage_products_latest_section_bg_color',
                array(
                    'type' => 'theme_mod',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'default'              => '',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_color'),
                )
                );
            $wp_customise->add_control(
                new WP_Customize_Color_Control(
                    $wp_customise,
                    'productive_ecommerce_homepage_products_latest_section_bg_color',
                    array(
                        'priority' => 70,
                        'label' => __( 'Background Colour', 'productive-ecommerce' ),
                        'section' => 'productive_ecommerce_homepage_products_latest_options',
                    )
                    )
                );
            */
        }
        
        
    } // End of class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Homepage_Products_Latest', 'register' ) );
    
    
    /**
     * Method productive_ecommerce_homepage_products_latest_enable.
     *
     * @param string $class ''.
     */
    function productive_ecommerce_homepage_products_latest_enable( $class = '' ) {
        return get_theme_mod( 'productive_ecommerce_homepage_products_latest_enable', true);
    }

    /**
     * Method productive_ecommerce_homepage_products_latest_section_title.
     *
     * @param string $class ''.
     */
    function productive_ecommerce_homepage_products_latest_section_title( $class = '' ) {
        return get_theme_mod( 'productive_ecommerce_homepage_products_latest_section_title', esc_html__( 'Latest Products', 'productive-ecommerce' ) );
    }

    /**
     * Method productive_ecommerce_homepage_products_latest_num_cols.
     *
     * @param string $class ''.
     */
    function productive_ecommerce_homepage_products_latest_num_cols( $class = '' ) {
        return get_theme_mod( 'productive_ecommerce_homepage_products_latest_num_cols', 4 );
    }

    /**
     * Method productive_ecommerce_homepage_products_latest_num_rows.
     *
     * @param string $class ''.
     */
    function productive_ecommerce_homepage_products_latest_num_rows( $class = '' ) {
        return get_theme_mod( 'productive_ecommerce_homepage_products_latest_num_rows', 1 );
    }

    /**
     * Method productive_ecommerce_homepage_products_latest_order.
     *
     * @param string $class ''.
     */
    function productive_ecommerce_homepage_products_latest_order( $class = '' ) {
        return get_theme_mod( 'productive_ecommerce_homepage_products_latest_order', 1 );
    }

    /**
     * Method productive_ecommerce_homepage_products_latest_style.
     *
     * @param string $class ''.
     */
    function productive_ecommerce_homepage_products_latest_style( $class = '' ) {
        return get_theme_mod( 'productive_ecommerce_homepage_products_latest_style', '' );
    }
    
    /**
     * Method productive_ecommerce_homepage_products_latest_section_bg_color.
     *
     * @param string $class ''.
     */
    function productive_ecommerce_homepage_products_latest_section_bg_color( $class = '' ) {
        return get_theme_mod( 'productive_ecommerce_homepage_products_latest_section_bg_color', '' );
    }

    
} // End of if class exists
