<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Layout' ) ) {
    
    /**
     * Productive_Theme_Customiser_Layout
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Layout extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            // Section
            $wp_customise->add_section(
                'productive_ecommerce_layout_options',
                array(
                    'title' => __( 'Layout Options', 'productive-ecommerce' ),
                    'description' => __( 'Layout Options', 'productive-ecommerce' ),
                    'panel' => 'productive_ecommerce_theme_options',
                    'priority' => 80,
                    'capability' => 'edit_theme_options',
                )
                );
            
            // add a setting for productive_ecommerce_page_banner_image control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_page_banner_image',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_image'),
                )
                );
                
            // add a setting for productive_ecommerce_template_layout_options control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_template_layout_options',
                array(
                    'type' => 'theme_mod',
                    'default' => 'one_column',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_template_layout_options',
                array(
                    'type' => 'select',
                    'priority' => 10,
                    'section' => 'productive_ecommerce_layout_options',
                    'label' => __( 'Site-wide Page Layout Options', 'productive-ecommerce' ),
                    'description' => '',
                    'choices' => array(
                        'one_column' => __( 'One Column', 'productive-ecommerce' ),
                        'two_columns_left' => __( 'Left Sidebar', 'productive-ecommerce' ),
                        'two_columns_right' => __( 'Right Sidebar', 'productive-ecommerce' ),
                        'three_columns' => __( 'Three columns', 'productive-ecommerce' ),
                    ),
                )
            );
            
            // add control.
            $wp_customise->add_control(
                new WP_Customize_Media_Control(
                    $wp_customise,
                    'productive_ecommerce_page_banner_image',
                    array(
                        'priority' => 29,
                        'section' => 'productive_ecommerce_layout_options',
                        'label' => __( 'Header Banner Image', 'productive-ecommerce' ),
                        'description' => __( 'Site-wide Header banner image', 'productive-ecommerce' ),
                        // 'active_callback' => 'is_front_page'
                    )
                    )
                );
            
            // add a setting for productive_ecommerce_show_top_banner control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_show_top_banner',
                array(
                    'type' => 'theme_mod',
                    'default' => 'hide_top_banner',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_show_top_banner',
                array(
                    'type' => 'select',
                    'priority' => 32,
                    'section' => 'productive_ecommerce_layout_options',
                    'label' => __( 'Header Banner Option', 'productive-ecommerce' ),
                    'description' => '',
                    'choices' => array(
                        'full_width_top_banner' => __( 'Set as Full Width', 'productive-ecommerce' ),
                        'page_width_top_banner' => __( 'Fit into Page Content', 'productive-ecommerce' ),
                        'hide_top_banner' => __( 'Hide Header Banner', 'productive-ecommerce' ),
                    ),
                )
            );
            
        }
        
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Layout', 'register' ) );
    
}// End of if class exists



/**
 * Method productive_ecommerce_template_layout_options.
 *
 * @param string $class ''.
 */
function productive_ecommerce_template_layout_options( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_template_layout_options', 'one_column' );
}

/**
 * Method productive_ecommerce_page_banner_image.
 *
 * @param string $class ''.
 */
function productive_ecommerce_page_banner_image() {
    return get_theme_mod( 'productive_ecommerce_page_banner_image' );
}

/**
 * Method productive_ecommerce_show_top_banner.
 *
 * @param string $class ''.
 */
function productive_ecommerce_show_top_banner( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_show_top_banner', 'hide_top_banner' );
}

/**
 * Method display_productive_ecommerce_layout_fullwidth.
 *
 * @param string $class ''.
 */
function productive_ecommerce_layout_fullwidth( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_layout_fullwidth', false );
}
add_action( 'display_productive_ecommerce_layout_fullwidth', 'productive_ecommerce_layout_fullwidth' );

/**
 * Method productive_ecommerce_layout_content_width.
 *
 * @param string $class ''.
 */
function productive_ecommerce_layout_content_width( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_layout_content_width', 0 );
}

