<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Homepage_Power_Button' ) ) {
    
    /**
     * Productive_Theme_Customiser_Homepage_Power_Button
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Homepage_Power_Button extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            // Section
            $panel = 'productive_ecommerce_theme_homepage_options';
            if ( productive_ecommerce_is_productive_style_active() ) {
                $panel = 'productive_style_theme_options_homepage';
            }
            $wp_customise->add_section(
                'productive_ecommerce_homepage_power_button_options',
                array(
                    'title' => __( 'Power Button', 'productive-ecommerce' ),
                    'description' => __( 'Power Button Styles', 'productive-ecommerce' ),
                    'panel' => $panel,
                    'priority' => 20,
                    'capability' => 'edit_theme_options',
                )
                );
            
            
            // add a setting for productive_ecommerce_power_button_title, below.
            $wp_customise->add_setting(
                'productive_ecommerce_power_button_title',
                array(
                    'type' => 'theme_mod',
                    'default' => __( 'Download Now', 'productive-ecommerce' ),
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_power_button_title',
                array(
                    'type' => 'text',
                    'priority' => 10,
                    'section' => 'productive_ecommerce_homepage_power_button_options',
                    'label' => __( 'Button Text', 'productive-ecommerce' ),
                    'description' => '',
                )
                );
            
            // add a setting for productive_ecommerce_power_button_url, below.
            $wp_customise->add_setting(
                'productive_ecommerce_power_button_url',
                array(
                    'type' => 'theme_mod',
                    'default' => '#',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_url'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_power_button_url',
                array(
                    'type' => 'text',
                    'priority' => 20,
                    'section' => 'productive_ecommerce_homepage_power_button_options',
                    'label' => __( 'Url', 'productive-ecommerce' ),
                    'description' => __( 'Full Url starting with &#39;http&#39; (leave empty to disable button)', 'productive-ecommerce' ),
                )
                );
            
            // add a setting for productive_ecommerce_power_button_font_color control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_power_button_font_color',
                array(
                    'type' => 'theme_mod',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'default'              => '',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_color'),
                )
                );
            
            $wp_customise->add_control(
                new WP_Customize_Color_Control(
                    $wp_customise,
                    'productive_ecommerce_power_button_font_color',
                    array(
                        'priority' => 30,
                        'label' => __( 'Text Color', 'productive-ecommerce' ),
                        'section' => 'productive_ecommerce_homepage_power_button_options',
                    )
                    )
                );
            
            // add a setting for productive_ecommerce_power_button_font_color_hover control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_power_button_font_color_hover',
                array(
                    'type' => 'theme_mod',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'default'              => '',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_color'),
                )
                );
            
            $wp_customise->add_control(
                new WP_Customize_Color_Control(
                    $wp_customise,
                    'productive_ecommerce_power_button_font_color_hover',
                    array(
                        'priority' => 32,
                        'label' => __( 'Text Color (on hover)', 'productive-ecommerce' ),
                        'section' => 'productive_ecommerce_homepage_power_button_options',
                    )
                    )
                );
            
            // add a setting for productive_ecommerce_power_button_bg_color control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_power_button_bg_color',
                array(
                    'type' => 'theme_mod',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'default'              => '',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_color'),
                )
                );
            
            $wp_customise->add_control(
                new WP_Customize_Color_Control(
                    $wp_customise,
                    'productive_ecommerce_power_button_bg_color',
                    array(
                        'priority' => 40,
                        'label' => __( 'Background Color', 'productive-ecommerce' ),
                        'section' => 'productive_ecommerce_homepage_power_button_options',
                    )
                    )
                );
            
            // add a setting for productive_ecommerce_power_button_bg_color_hover control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_power_button_bg_color_hover',
                array(
                    'type' => 'theme_mod',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'default'              => '',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_color'),
                )
                );
            
            $wp_customise->add_control(
                new WP_Customize_Color_Control(
                    $wp_customise,
                    'productive_ecommerce_power_button_bg_color_hover',
                    array(
                        'priority' => 42,
                        'label' => __( 'Background Color (on hover)', 'productive-ecommerce' ),
                        'section' => 'productive_ecommerce_homepage_power_button_options',
                    )
                    )
                );
            
            // add a setting for productive_ecommerce_power_button_shape control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_power_button_shape',
                array(
                    'type' => 'theme_mod',
                    'default' => 'ellipse',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_power_button_shape',
                array(
                    'type' => 'select',
                    'priority' => 50,
                    'section' => 'productive_ecommerce_homepage_power_button_options',
                    'label' => __( 'Button Shape', 'productive-ecommerce' ),
                    'description' => '',
                    'choices' => productive_ecommerce_get_button_radius_shapes(),
                )
            );
            
            
            
            if ( productive_ecommerce_is_productive_style_active() ) {
                // add a setting for productive_ecommerce_power_button_font_family control, below.
                $wp_customise->add_setting(
                    'productive_ecommerce_power_button_font_family',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                    )
                );

                // add control...
                $wp_customise->add_control(
                    'productive_ecommerce_power_button_font_family',
                    array(
                        'type' => 'select',
                        'priority' => 70,
                        'section' => 'productive_ecommerce_homepage_power_button_options',
                        'label' => __( 'Font Family', 'productive-ecommerce' ),
                        'description' => '',
                        'choices' => productive_style_customiser_get_font_families(),
                    )
                );

                // add a setting for productive_ecommerce_power_button_font_style control, below.
                $wp_customise->add_setting(
                    'productive_ecommerce_power_button_font_style',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                    )
                );

                // add control...
                $wp_customise->add_control(
                    'productive_ecommerce_power_button_font_style',
                    array(
                        'type' => 'select',
                        'priority' => 80,
                        'section' => 'productive_ecommerce_homepage_power_button_options',
                        'label' => __( 'Font Style', 'productive-ecommerce' ),
                        'description' => '',
                        'choices' => productive_style_customiser_get_font_styles()
                    )
                );

                // add a setting for productive_ecommerce_power_button_font_size control, below.
                $wp_customise->add_setting(
                    'productive_ecommerce_power_button_font_size',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_float'),
                    )
                );
                $wp_customise->add_control(
                    'productive_ecommerce_power_button_font_size', 
                    array(
                        'type' => 'number',
                        'priority' => 90,
                        'section' => 'productive_ecommerce_homepage_power_button_options',
                        'label' => __( 'Font Size (rem)', 'productive-ecommerce' ),
                        'description' => __( 'This size is scaled relatively across the various elements of the website.', 'productive-ecommerce' ),
                        'input_attrs' => array(
                            'min' => PRODUCTIVE_STYLE_FONT_SIZE_MIN,
                            'max' => PRODUCTIVE_STYLE_FONT_SIZE_MAX,
                            'step' => PRODUCTIVE_STYLE_FONT_SIZE_STEP,
                        ),
                    )
                );

                // add a setting for productive_ecommerce_power_button_font_weight control, below.
                $wp_customise->add_setting(
                    'productive_ecommerce_power_button_font_weight',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                    )
                );

                // add control...
                $wp_customise->add_control(
                    'productive_ecommerce_power_button_font_weight',
                    array(
                        'type' => 'select',
                        'priority' => 100,
                        'section' => 'productive_ecommerce_homepage_power_button_options',
                        'label' => __( 'Font Weight', 'productive-ecommerce' ),
                        'description' => '',
                        'choices' => productive_style_customiser_get_font_weights(),
                    )
                );

                // add a setting for productive_ecommerce_power_button_line_height control, below.
                $wp_customise->add_setting(
                    'productive_ecommerce_power_button_line_height',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_float'),
                    )
                );

                // add control...
                $wp_customise->add_control(
                    'productive_ecommerce_power_button_line_height',
                    array(
                        'type' => 'number',
                        'priority' => 110,
                        'section' => 'productive_ecommerce_homepage_power_button_options',
                        'label' => __( 'Line Height', 'productive-ecommerce' ),
                        'description' => '',
                        'input_attrs' => array(
                            'min' => PRODUCTIVE_STYLE_LINE_HEIGHT_SIZE_MIN,
                            'max' => PRODUCTIVE_STYLE_LINE_HEIGHT_SIZE_MAX,
                            'step' => PRODUCTIVE_STYLE_LINE_HEIGHT_SIZE_STEP,
                        ),
                    )
                );

                // add a setting for productive_ecommerce_power_button_text_transform control, below.
                $wp_customise->add_setting(
                    'productive_ecommerce_power_button_text_transform',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                    )
                );

                // add control...
                $wp_customise->add_control(
                    'productive_ecommerce_power_button_text_transform',
                    array(
                        'type' => 'select',
                        'priority' => 120,
                        'section' => 'productive_ecommerce_homepage_power_button_options',
                        'label' => __( 'Text Transformation', 'productive-ecommerce' ),
                        'description' => '',
                        'choices' => productive_style_customiser_get_font_transforms()
                    )
                );

                // add a setting for productive_ecommerce_power_button_text_decoration control, below.
                $wp_customise->add_setting(
                    'productive_ecommerce_power_button_text_decoration',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                    )
                );

                // add control...
                $wp_customise->add_control(
                    'productive_ecommerce_power_button_text_decoration',
                    array(
                        'type' => 'select',
                        'priority' => 130,
                        'section' => 'productive_ecommerce_homepage_power_button_options',
                        'label' => __( 'Text Decoration', 'productive-ecommerce' ),
                        'description' => '',
                        'choices' => productive_style_customiser_get_font_decorations()
                    )
                );
            }
            
            
        }
        
    } // End of class.
    if ( function_exists( 'productiveminds_is_productive_power_button' ) && productiveminds_is_productive_power_button() ) {
        // add hook for the class.
        add_action( 'customize_register', array( 'Productive_Theme_Customiser_Homepage_Power_Button', 'register' ) );
    }
    
} // End of if class exists


/**
 * Method productive_ecommerce_power_button_title.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_title( $class = '' ) {
    $theme_mod_value = get_theme_mod( 'productive_ecommerce_power_button_title', esc_html__( 'Gifts For Her', 'productive-ecommerce' ) );
    $cta_url = productive_ecommerce_power_button_url();
    if ( $theme_mod_value != '' && $cta_url != '' ) {
        $theme_mod_value = wp_specialchars_decode(stripslashes($theme_mod_value) );
        echo '<a class="header-power-button-link" aria-label="' . esc_attr($theme_mod_value) . '" title="' . esc_attr($theme_mod_value) . '" href="'. esc_url($cta_url) .'">' . esc_attr($theme_mod_value) .
            '</a>';
    }
} 
add_action( 'display_productive_ecommerce_power_button_title', 'productive_ecommerce_power_button_title' );

/**
 * Method productive_ecommerce_power_button_url.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_url( $class = '' ) {
    // text html
    $theme_mod_value = get_theme_mod( 'productive_ecommerce_power_button_url', '#' );
    return wp_specialchars_decode( esc_url( $theme_mod_value ) );
}
add_action( 'display_productive_ecommerce_power_button_url', 'productive_ecommerce_power_button_url' );

/**
 * Method productive_ecommerce_power_button_font_color.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_font_color( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_font_color', '#ffffff' );
}

/**
 * Method productive_ecommerce_power_button_font_color_hover.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_font_color_hover( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_font_color_hover', '#ffffff' );
}

/**
 * Method productive_ecommerce_power_button_bg_color.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_bg_color( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_bg_color', '#a40564' );
}

/**
 * Method productive_ecommerce_power_button_bg_color_hover.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_bg_color_hover( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_bg_color_hover', '#a40564' );
}

/**
 * Method productive_ecommerce_power_button_shape.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_shape( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_shape', 'ellipse' );
}

/**
 * Method productive_ecommerce_power_button_font_family.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_font_family( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_font_family', '' );
}

/**
 * Method productive_ecommerce_power_button_font_style.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_font_style( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_font_style', '' );
}

/**
 * Method productive_ecommerce_power_button_font_size.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_font_size( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_font_size', '' );
}

/**
 * Method productive_ecommerce_power_button_font_weight.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_font_weight( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_font_weight', '' );
}

/**
 * Method productive_ecommerce_power_button_line_height.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_line_height( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_line_height', '' );
}

/**
 * Method productive_ecommerce_power_button_text_transform.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_text_transform( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_text_transform', '' );
}

/**
 * Method productive_ecommerce_power_button_text_decoration.
 *
 * @param string $class ''.
 */
function productive_ecommerce_power_button_text_decoration( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_power_button_text_decoration', '' );
}
