<?php
/**
 *
 * @package productive-ecommerce
 */

if ( !defined('ABSPATH') ) {
	die();
}

require PRODUCTIVE_ECOMMERCE_THEME_BASE_PATH . '/admin/common/options/global/global-settings-admin.php';

require PRODUCTIVE_ECOMMERCE_THEME_BASE_PATH . '/admin/common/options/partials/theme-dashboard.php';
require PRODUCTIVE_ECOMMERCE_THEME_BASE_PATH . '/standard/options/partials/section-go-pro.php';
require PRODUCTIVE_ECOMMERCE_THEME_BASE_PATH . '/includes/productiveminds-theme-dashboad-items.php';

$productive_ecommerce_admin_navbar_title = PRODUCTIVE_ECOMMERCE_CURRENT_THEME_NAME . esc_html__( ' Admin Settings and Options', 'productive-ecommerce' );
$productive_ecommerce_admin_topmenu_title   = esc_html('Productive...');

/**
 * Render Pages and Menus
 * 
 * @global string $productive_ecommerce_admin_navbar_title
 */
function productive_ecommerce_plugin_options_render_page_menu() {
    
    global $productive_ecommerce_admin_navbar_title;
    global $productive_ecommerce_admin_topmenu_title;
        
    $menu_title         = PRODUCTIVE_ECOMMERCE_OPTION_MENU_TITLE;
    $capability         = 'administrator';          // allowed user role.
    $position           = 100;
    $icon_url           = 'dashicons-carrot';
    $position_global    = 60; // Just after the Appearnce Page Menu
    
    add_theme_page( 
        $productive_ecommerce_admin_navbar_title, 
        $menu_title, 
        $capability, 
        PRODUCTIVE_ECOMMERCE_ADMIN_PAGE_REQUEST_URI, 
        'productive_ecommerce_plugin_options_render_page_menu_html', 
        $position
    );
    
    // Plugin Custom Top-Level Menu & SubMenu
    // Register a new section in the "productive_ecommerce" page.
    add_menu_page(
        $productive_ecommerce_admin_navbar_title, // Browser navbar title
        $productive_ecommerce_admin_topmenu_title, // Sidebar menu text
        $capability,
        PRODUCTIVE_ECOMMERCE_ADMIN_OVERVIEW_REQUEST_URI, // Unique id, which will be used to bind submenus to this top menu
        'productive_ecommerce_plugin_options_render_page_menu_html', // Callback function for the menu
        $icon_url, 
        $position_global,
    );
   
    // Add global content
    productive_global_plugin_options_render_page_menu_global();
   
    // Plugin Custom Top-Level Menu & SubMenu
    // Register a new section in the "productive_ecommerce" page.
    add_submenu_page(
        PRODUCTIVE_ECOMMERCE_ADMIN_OVERVIEW_REQUEST_URI,
        $productive_ecommerce_admin_navbar_title, // Browser navbar title
        $menu_title, // Sidebar menu text
        $capability,
        PRODUCTIVE_ECOMMERCE_ADMIN_PAGE_REQUEST_URI, // Unique id
        'productive_ecommerce_plugin_options_render_page_menu_html' // Callback function for the menu
    );
}
add_action( 'admin_menu', 'productive_ecommerce_plugin_options_render_page_menu' );


function productive_ecommerce_options_main_init() {
    // Add global sections
    productive_global_register_sections();
}
add_action( 'admin_init', 'productive_ecommerce_options_main_init' );


function productive_ecommerce_plugin_options_render_page_menu_html() {
    // check user capabilities
    if ( !current_user_can( 'manage_options' ) ) {
        add_settings_error( 'productive_ecommerce_admin_messages', 'productive_ecommerce_admin_message', esc_html__( 'You do not have permission to access this page.', 'productive-ecommerce' ), 'error' );
        settings_errors( 'productive_ecommerce_admin_messages' );
    } else {
            
    // check if the user have submitted the settings
    $is_error_count_section_1 = count( get_settings_errors('productiveminds_section_1_options') );
    if ( isset( $_GET['settings-updated'] ) && $is_error_count_section_1 < 1 ) {
        // add settings saved message with the class of "updated"
        add_settings_error( 'productive_ecommerce_admin_messages', 'productive_ecommerce_admin_message', __( 'Settings Saved', 'productive-ecommerce' ), 'updated' );
    }
    settings_errors( 'productive_ecommerce_admin_messages' );
    
    ?>
    <?php 
        $active_tab = 'section_about_options_tab';
            if( isset( $_GET[ 'tab' ] ) ) {
                $active_tab = sanitize_text_field( $_GET[ 'tab' ] );
            }		
    ?>

    <div class="wrap productive-global-options-page-wrapper">
        <div class="page-wrapper-heading-container">
            <div class="page-wrapper-heading">
                <h1>
                    <img style="vertical-align: middle; margin-right: 10px; border-radius: 5px;" src="<?php echo PRODUCTIVE_ECOMMERCE_THEME_BASE_URI . '/screenshot.png' ?>" alt="" width="40px" height="auto" />
                    <?php echo PRODUCTIVE_ECOMMERCE_CURRENT_THEME_NAME; ?>
                    <a target="_blank" class="page-wrapper-heading-get-pro" href="<?php echo PRODUCTIVE_ECOMMERCE_THEME_DOCUMENTATION_URL; ?>"><?php _e( 'Documentation', 'productive-ecommerce' ); ?></a>
                    <a target="_blank" class="page-wrapper-heading-get-pro" href="<?php echo PRODUCTIVE_ECOMMERCE_THEME_SUPPORT_URL; ?>"><?php _e( 'Get Support', 'productive-ecommerce' ); ?></a>
                </h1>
            </div>
            <div class="page-wrapper-heading-version">
                <div><?php echo 'v' . PRODUCTIVE_ECOMMERCE_VERSION; ?></div>
            </div>
        </div>
        <div class="page-wrapper-body">
                
            <div class="page-wrapper-options-error">
                <?php settings_errors('productiveminds_section_1_options'); ?>
                <?php settings_errors('productiveminds_section_pro_options'); ?>
            </div>

            <?php
                $section_about_options_tab = '';
                if ( $active_tab === 'section_about_options_tab' ) {
                    $section_about_options_tab = 'nav-tab-active';
                }
                $section_pro_options_tab = '';
                if ( $active_tab === 'section_pro_options_tab' ) {
                    $section_pro_options_tab = 'nav-tab-active';
                }
            ?>
            <h2 class="nav-tab-wrapper">
                <a href="?page=<?php echo PRODUCTIVE_ECOMMERCE_ADMIN_PAGE_REQUEST_URI; ?>&tab=section_about_options_tab" class="nav-tab <?php echo esc_attr( $section_about_options_tab ); ?>"><?php echo PRODUCTIVE_ECOMMERCE_OPTION_TAB_1_TITLE; ?></a>
                <a href="?page=<?php echo PRODUCTIVE_ECOMMERCE_ADMIN_PAGE_REQUEST_URI; ?>&tab=section_pro_options_tab" class="nav-tab <?php echo esc_attr( $section_pro_options_tab ); ?>"><?php echo PRODUCTIVE_ECOMMERCE_OPTION_TAB_PRO_TITLE; ?></a>
            </h2>
            
            <div class="page-wrapper-body-form">
                
                <?php if ( $active_tab === 'section_about_options_tab' ) { ?>
                    <div class="productiveminds_double_grid column_70_30">
                        <div class="productiveminds_double_grid_content">
                            <?php
                                productive_ecommerce_theme_dashboard_section_intro();
                                productive_ecommerce_theme_dashboard_section_content();
                                productive_ecommerce_theme_dashboard_section_customizers();
                                productive_ecommerce_theme_dashboard_section_template_elementor();
                                productive_ecommerce_theme_dashboard_section_plugin_forms();
                                productive_ecommerce_theme_dashboard_section_plugin_commerce();
                            ?>
                        </div>
                        <div class="productiveminds_double_grid_content">
                            <?php
                                productive_ecommerce_theme_dashboard_section_about();
                            ?>
                        </div>
                    </div>
                <?php } else { ?>
                    <div class="productive-global-item-container">
                        
                        <?php if ( $active_tab === 'section_pro_options_tab' ) { ?>
                            <?php
                                productiveminds_section_get_pro();
                           ?>
                        <?php } ?>
                        
                    </div>
                <?php } ?>
            </div>
            
            <div class="leave-a-review-box">
                <?php _e( 'Support our efforts, interact with fellow users, and contribute to enhancing ', 'productive-ecommerce' ); ?>
                <?php echo PRODUCTIVE_ECOMMERCE_CURRENT_THEME_NAME; ?>.
                <a target="_blank" href="<?php echo PRODUCTIVE_ECOMMERCE_THEME_REVIEW_ON_REPO_URL; ?>">
                    <?php _e( 'Kindly submit a review', 'productive-ecommerce' ); ?>
               </a>
            </div>

        </div>
    </div>

    <?php
    }
}
